==> hlit_dev-0.0.0.7.tar.gz: hlit_dev-0.0.0.7/orangecontrib/HLIT_dev/widgets/OWStatutInterface.py <==
import os
import sys
import json
from Orange.widgets.widget import OWWidget, Input, Output
from Orange.widgets.settings import Setting
from Orange.widgets import gui
from AnyQt.QtWidgets import QLineEdit, QFileDialog, QApplication
from Orange.data import Table, Domain, StringVariable, ContinuousVariable


if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
    from Orange.widgets.orangecontrib.AAIT.utils import thread_management
    from Orange.widgets.orangecontrib.AAIT.utils.import_uic import uic
    from Orange.widgets.orangecontrib.HLIT_dev.remote_server_smb import server_uvicorn, convert
    from Orange.widgets.orangecontrib.AAIT.utils import MetManagement
else:
    from orangecontrib.AAIT.utils import thread_management
    from orangecontrib.AAIT.utils.import_uic import uic
    from orangecontrib.HLIT_dev.remote_server_smb import server_uvicorn,convert
    from orangecontrib.AAIT.utils import MetManagement

class OutputInterface(OWWidget):
    name = "StatutInteface"
    description = "Get the statut of the workflow in the local interface"
    icon = "icons/statut.png"
    if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
         icon = "icons_dev/statut.png"
    priority = 3000
    statut = Setting("")
    workflow_id = Setting("")

    class Inputs:
        data = Input("Data", Table)

    class Outputs:
        data = Output("Data", Table)

    @Inputs.data
    def set_data(self, in_data):
        if in_data is not None:
            self.data = in_data
            self.run()

    def __init__(self):
        super().__init__()
        self.data = None

        self.statut_input = QLineEdit(self)
        self.statut_input.setPlaceholderText("Value statut")
        self.statut_input.setText(self.statut)
        self.statut_input.editingFinished.connect(self.update_settings)
        gui.widgetBox(self.controlArea, orientation='vertical').layout().addWidget(self.statut_input)

        # Qt Management
        self.workflow_id_input = QLineEdit(self)
        self.workflow_id_input.setPlaceholderText("Workflow ID")
        self.workflow_id_input.setText(self.workflow_id)
        self.workflow_id_input.editingFinished.connect(self.update_settings)
        gui.widgetBox(self.controlArea, orientation='vertical').layout().addWidget(self.workflow_id_input)
        gui.button(self.controlArea, self, "Valider votre configuration", callback=self.run)

    def update_settings(self):
        self.statut = self.statut_input.text()
        self.workflow_id = self.workflow_id_input.text()

    def run(self):
        self.error("")
        self.warning("")

        if self.workflow_id == "":
            self.warning("Workflow ID manquant.")
            return

        if self.statut == "":
            self.warning("Statut manquant.")
            return

        path_file = MetManagement.get_api_local_folder()

        # On remet à jour les fichiers statuts
        file_to_delete = [path_file + ".statut_ok", path_file + "statut.json"]

        if os.path.exists(file_to_delete[0]) and os.path.exists(file_to_delete[1]):
            if MetManagement.reset_files(file_to_delete) != 0:
                self.error("Les fichiers statuts sont supprimés .")
                return

        # Execution of the workflow
        if not os.path.exists(path_file + "config.json"):
            self.error("Le fichier 'config.json' n'existe pas.")
            return

        with open(path_file + "config.json", "r", encoding="utf-8") as file:
            data = json.load(file)

        if self.workflow_id != data["workflow_id"]:
            self.error("Le workflow id ne correspond pas avec votre configuration.")
            return

        with open(path_file + "statut.json", "w") as fichier:
            json.dump({"value" : self.statut}, fichier, indent=4)
        with open(path_file + ".statut_ok", "w") as fichier:
            pass

        self.Outputs.data.send(self.data)

if __name__ == "__main__":
    app = QApplication(sys.argv)
    my_widget = OutputInterface()
    my_widget.show()
    app.exec_()

==> hlit_dev-0.0.0.13.tar.gz: hlit_dev-0.0.0.13/orangecontrib/HLIT_dev/widgets/OWStatutInterface.py <==
import os
import sys
import json
from Orange.widgets.widget import OWWidget, Input, Output
from Orange.widgets.settings import Setting
from Orange.widgets import gui
from AnyQt.QtWidgets import QLineEdit, QFileDialog, QApplication
from Orange.data import Table, Domain, StringVariable, ContinuousVariable


if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
    from Orange.widgets.orangecontrib.AAIT.utils import thread_management
    from Orange.widgets.orangecontrib.AAIT.utils.import_uic import uic
    from Orange.widgets.orangecontrib.HLIT_dev.remote_server_smb import server_uvicorn, convert
    from Orange.widgets.orangecontrib.AAIT.utils import MetManagement
else:
    from orangecontrib.AAIT.utils import thread_management
    from orangecontrib.AAIT.utils.import_uic import uic
    from orangecontrib.HLIT_dev.remote_server_smb import server_uvicorn,convert
    from orangecontrib.AAIT.utils import MetManagement

class OutputInterface(OWWidget):
    name = "Statut Interface"
    description = "Get the statut of the workflow in the local interface"
    icon = "icons/statut.png"
    if "site-packages/Orange/widgets" in os.path.dirname(os.path.abspath(__file__)).replace("\\", "/"):
         icon = "icons_dev/statut.png"
    priority = 3000
    statut = Setting("")
    workflow_id = Setting("")

    class Inputs:
        data = Input("Data", Table)

    class Outputs:
        data = Output("Data", Table)

    @Inputs.data
    def set_data(self, in_data):
        if in_data is not None:
            self.data = in_data
            self.run()

    def __init__(self):
        super().__init__()
        self.data = None

        self.statut_input = QLineEdit(self)
        self.statut_input.setPlaceholderText("Value statut")
        self.statut_input.setText(self.statut)
        self.statut_input.editingFinished.connect(self.update_settings)
        gui.widgetBox(self.controlArea, orientation='vertical').layout().addWidget(self.statut_input)

        # Qt Management
        self.workflow_id_input = QLineEdit(self)
        self.workflow_id_input.setPlaceholderText("Workflow ID")
        self.workflow_id_input.setText(self.workflow_id)
        self.workflow_id_input.editingFinished.connect(self.update_settings)
        gui.widgetBox(self.controlArea, orientation='vertical').layout().addWidget(self.workflow_id_input)
        gui.button(self.controlArea, self, "Valider votre configuration", callback=self.run)

    def update_settings(self):
        self.statut = self.statut_input.text()
        self.workflow_id = self.workflow_id_input.text()

    def run(self):
        self.error("")
        self.warning("")

        if self.workflow_id == "":
            self.warning("Workflow ID manquant.")
            return

        if self.statut == "":
            self.warning("Statut manquant.")
            return

        path_file = MetManagement.get_api_local_folder()

        # On remet à jour les fichiers statuts
        file_to_delete = [path_file + ".statut_ok", path_file + "statut.json"]

        if os.path.exists(file_to_delete[0]) and os.path.exists(file_to_delete[1]):
            if MetManagement.reset_files(file_to_delete) != 0:
                self.error("Les fichiers statuts sont supprimés .")
                return

        # Execution of the workflow
        if not os.path.exists(path_file + "config.json"):
            #self.error("Le fichier 'config.json' n'existe pas.")
            return

        with open(path_file + "config.json", "r", encoding="utf-8") as file:
            data = json.load(file)

        if self.workflow_id != data["workflow_id"]:
            self.error("Le workflow id ne correspond pas avec votre configuration.")
            return

        with open(path_file + "statut.json", "w") as fichier:
            json.dump({"value" : self.statut}, fichier, indent=4)
        with open(path_file + ".statut_ok", "w") as fichier:
            pass

        self.Outputs.data.send(self.data)

if __name__ == "__main__":
    app = QApplication(sys.argv)
    my_widget = OutputInterface()
    my_widget.show()
    app.exec_()
